@@ -1,33 +1,33 @@
 from pydantic import BaseModel, ValidationError
-from typing import Union, Optional, List
+from typing import Union, Optional, List, Any
 
 from moloni.base.client import MoloniBaseClient
 from moloni.base.helpers import endpoint, fill_query_params, validate_data
 
 
 class Associated_documents(BaseModel):
-    associated_id: Optional[Union[str, int]]
-    value: Optional[Union[str, int]]
+    associated_id: Optional[Any] = None
+    value: Optional[Any] = None
 
 
 class Payments(BaseModel):
-    date: Optional[Union[str, int]]
-    notes: Optional[Union[str, int]]
-    payment_method_id: Optional[Union[str, int]]
-    value: Optional[Union[str, int]]
+    date: Optional[Any] = None
+    notes: Optional[Any] = None
+    payment_method_id: Optional[Any] = None
+    value: Optional[Any] = None
 
 
 class Products(BaseModel):
-    discount: Optional[Union[str, int]]
-    exemption_reason: Optional[Union[str, int]]
-    name: Optional[Union[str, int]]
-    order: Optional[Union[str, int]]
-    price: Optional[Union[str, int]]
-    product_id: Optional[Union[str, int]]
-    qty: Optional[Union[str, int]]
-    summary: Optional[Union[str, int]]
-    taxes: Optional[Union[str, int]]
-    warehouse_id: Optional[Union[str, int]]
+    discount: Optional[Any] = None
+    exemption_reason: Optional[Any] = None
+    name: Optional[Any] = None
+    order: Optional[Any] = None
+    price: Optional[Any] = None
+    product_id: Optional[Any] = None
+    qty: Optional[Any] = None
+    summary: Optional[Any] = None
+    taxes: Optional[Any] = None
+    warehouse_id: Optional[Any] = None
 
 
 class InvoicereceiptsCountModel(BaseModel):
